pub enum ControllerRequest {
WatchDeviceState {
responder: ControllerWatchDeviceStateResponder,
},
#[non_exhaustive] _UnknownMethod {
ordinal: u64,
control_handle: ControllerControlHandle,
method_type: MethodType,
},
}Expand description
Protocol for communicating with a low-level USB hardware controller.
This interface allows the USB policy component to act as a client and monitor the hardware’s state.
Variants
WatchDeviceState
Notify a client of an updated device state value via a hanging get. The first time this is called, it will return right away with the current state. Subsequent calls will hang until there is a change to report. Returns a table containing the updated device state.
Fields

responder: ControllerWatchDeviceStateResponder#[non_exhaustive]_UnknownMethod
An interaction was received which does not match any known method.
Fields
This variant is marked as non-exhaustive
Non-exhaustive enum variants could have additional fields added in future. Therefore, non-exhaustive enum variants cannot be constructed in external crates and cannot be matched against.

control_handle: ControllerControlHandle
method_type: MethodTypeImplementations
Sourceimpl ControllerRequest
impl ControllerRequest
pub fn into_watch_device_state( self, ) -> Option<ControllerWatchDeviceStateResponder>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL