pub struct DeviceStateWatcherMarker;Trait Implementations
Sourceimpl Clone for DeviceStateWatcherMarker
impl Clone for DeviceStateWatcherMarker
Sourcefn clone(&self) -> DeviceStateWatcherMarker
fn clone(&self) -> DeviceStateWatcherMarker
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceStateWatcherMarker
impl Debug for DeviceStateWatcherMarker
Sourceimpl Hash for DeviceStateWatcherMarker
impl Hash for DeviceStateWatcherMarker
Sourceimpl Ord for DeviceStateWatcherMarker
impl Ord for DeviceStateWatcherMarker
Sourcefn cmp(&self, other: &DeviceStateWatcherMarker) -> Ordering
fn cmp(&self, other: &DeviceStateWatcherMarker) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for DeviceStateWatcherMarker
impl PartialEq for DeviceStateWatcherMarker
Sourceimpl PartialOrd for DeviceStateWatcherMarker
impl PartialOrd for DeviceStateWatcherMarker
Sourceimpl ProtocolMarker for DeviceStateWatcherMarker
impl ProtocolMarker for DeviceStateWatcherMarker
Sourceconst DEBUG_NAME: &'static str = "(anonymous) DeviceStateWatcher"
const DEBUG_NAME: &'static str = "(anonymous) DeviceStateWatcher"
The name of the protocol suitable for debug purposes. Read more
Sourcetype Proxy = DeviceStateWatcherProxy
type Proxy = DeviceStateWatcherProxy
The type of the structure against which FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.Sourcetype RequestStream = DeviceStateWatcherRequestStream
type RequestStream = DeviceStateWatcherRequestStream
The type of the stream of requests coming into a server.
Sourcetype SynchronousProxy = DeviceStateWatcherSynchronousProxy
type SynchronousProxy = DeviceStateWatcherSynchronousProxy
The type of the structure against which thread-blocking FIDL requests are made.
Queries made against the proxy are sent to the paired
ServerEnd.impl Copy for DeviceStateWatcherMarker
impl Eq for DeviceStateWatcherMarker
impl StructuralPartialEq for DeviceStateWatcherMarker