pub struct DeviceStateWatcherSynchronousProxy { /* private fields */ }Implementations
Sourceimpl DeviceStateWatcherSynchronousProxy
impl DeviceStateWatcherSynchronousProxy
pub fn new(channel: Channel) -> Self
pub fn into_channel(self) -> Channel
Sourcepub fn wait_for_event(
&self,
deadline: MonotonicInstant,
) -> Result<DeviceStateWatcherEvent, Error>
pub fn wait_for_event( &self, deadline: MonotonicInstant, ) -> Result<DeviceStateWatcherEvent, Error>
Waits until an event arrives and returns it. It is safe for other threads to make concurrent requests while waiting for an event.
Sourcepub fn watch_device_state(
&self,
___deadline: MonotonicInstant,
) -> Result<DeviceStateWatcherWatchDeviceStateResult, Error>
pub fn watch_device_state( &self, ___deadline: MonotonicInstant, ) -> Result<DeviceStateWatcherWatchDeviceStateResult, Error>
Notify a client of an updated device state value via a hanging get. The first time this is called, it will return right away with the current state. Subsequent calls will hang until there is a change to report. Returns a table containing the updated device state.